/*****************************************/
/*       STATA command file for          */
/* "Electoral Strategies of Prefectural  */
/*     Assembly Members and their        */
/*            Vote Share"                */
/*    Leviathan 51, 2012 Fall            */
/*   (c)2012 Yoshitaka Nishizawa         */
/*****************************************/


/**********************************/
/* Inporting spss outfile here    */
/**********************************/

/* The 'SOLaR2010_release3_2012May10_v1-ynSTATA.dta'           */
/* spss outfile was read into a new data file by File > Open.  */

summarize
set more off

recode sup_shug sup_sang sup_govn sup_mayo sup_city   ///
       hel_shug hel_sang hel_govn hel_mayo hel_city   ///
       Dist3cat (-9=.)

summarize sup_shug sup_sang sup_govn sup_mayo sup_city   ///
       hel_shug hel_sang hel_govn hel_mayo hel_city   ///
       Dist3cat
set more off
   


/**********************************/
/*      Analysis begins here      */
/**********************************/

gen sampling=runiform()


/**********************************/
/*        fig 5 and figs 6        */
/**********************************/

/* DVshare by age 40% by Dist3cat = all   */
twoway (scatter DVshare age if (sampling < .4), msymbol(Oh) mcolor (gs9) legend(cols(3) label(1 "all parties (40%)"))) ///  
       (lfitci DVshare age, ciplot(rline) lcolor(gs9)),          ///
       graphregion(c(white) ls(none))                            /* <<< Table 5 >>> */ 
                                                                 /* The width of fitted line, manually thicked for the final report */

/* DVshare by age 20% by Dist3cat = 1   */
twoway (scatter DVshare age if (sampling < .2) & (Dist3cat == 2 | Dist3cat == 4), msymbol(Oh) mcolor (gs9) legend(cols(3) label(1 "Dist Size: 2+"))) /// 
       (lfitci DVshare age if (Dist3cat == 2 | Dist3cat == 4), ciplot(rline) lcolor(gs9))                                                            ///
       (scatter DVshare age if (sampling < .2) & (Dist3cat == 1), msymbol(.) mcolor (black) legend(cols(3) label(4 "Dist Size: 1")))                 ///
       (lfitci DVshare age if Dist3cat == 1, ciplot(rline) lcolor(black)),                                                                           ///
       graphregion(c(white) ls(none))                              /* <<< Table 6a >>> */  
/* DVshare by age 20% by Dist3cat = 2   */
twoway (scatter DVshare age if (sampling < .2) & (Dist3cat == 1 | Dist3cat == 4), msymbol(Oh) mcolor (gs9) legend(cols(3) label(1 "Dist Size: 1 or 4+"))) /// 
       (lfitci DVshare age if (Dist3cat == 1 | Dist3cat == 4), ciplot(rline) lcolor(gs9))                                                                 ///
       (scatter DVshare age if (sampling < .2) & (Dist3cat == 2), msymbol(.) mcolor (black) legend(cols(3) label(4 "Dist Size: 2")))                      ///
       (lfitci DVshare age if Dist3cat == 2, ciplot(rline) lcolor(black)),                                                                                ///
       graphregion(c(white) ls(none))                              /* <<< Table 6b >>> */  
/* DVshare by age 20% by Dist3cat = 4   */
twoway (scatter DVshare age if (sampling < .2) & (Dist3cat == 1 | Dist3cat == 2), msymbol(Oh) mcolor (gs9) legend(cols(3) label(1 "Dist Size: 1 - 3"))) /// 
       (lfitci DVshare age if (Dist3cat == 1 | Dist3cat == 2), ciplot(rline) lcolor(gs9))                                                               ///
       (scatter DVshare age if (sampling < .2) & (Dist3cat == 4), msymbol(.) mcolor (black) legend(cols(3) label(4 "Dist Size: 4+")))                   ///
       (lfitci DVshare age if Dist3cat == 4, ciplot(rline) lcolor(black)),                                                                              ///
       graphregion(c(white) ls(none))                              /* <<< Table 6c >>> */ 
      

/**********************************/
/*     reg and test linear com    */
/**********************************/

/*:::::::::::::::: Table 6 :::::::::::::::::::*/
/* Dist3cat==1 */
regress DVshare age Mterms Mcands  ///
    dpj ldp cgp sdp jcp prim dpj_prim ldp_prim if Dist3cat==1 

lincom prim + ldp_prim  
/*
 ( 1)  prim + ldp_prim = 0

------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |    .644593   .2399799     2.69   0.009      .167758    1.121428
------------------------------------------------------------------------------
*/

/* Dist3cat==2 */
regress DVshare age Mterms Mcands  ///
    dpj ldp cgp sdp jcp prim dpj_prim ldp_prim if Dist3cat==2 

lincom jcp
/*
 ( 1)  jcp = 0

------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |  -19.92284   7.588251    -2.63   0.009    -34.85809   -4.987598
------------------------------------------------------------------------------
*/
 
/* Dist3cat==4 */
regress DVshare age Mterms Mcands  ///
    dpj ldp cgp sdp jcp prim dpj_prim ldp_prim if Dist3cat==4 

lincom dpj
lincom cgp
/*
 ( 1)  dpj = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   10.97888   4.597032     2.39   0.017     1.939612    20.01815
------------------------------------------------------------------------------

 ( 1)  cgp = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   13.08312   3.832941     3.41   0.001     5.546307    20.61994
------------------------------------------------------------------------------
*/
 
lincom prim + dpj_prim
/*
 ( 1)  prim + dpj_prim = 0

------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |  -1.227856   .5121688    -2.40   0.017    -2.234947   -.2207644
------------------------------------------------------------------------------
*/





/*:::::::::::::::: Table 8 :::::::::::::::::::*/
/* Dist3cat==1 */
/*     polact1 */
regress DVshare age Mterms Mcands  ///
    dpj ldp cgp sdp jcp prim dpj_prim ldp_prim ///
    polact1 polact2 polact3 polact4 ///
    a_pol1 a_pol2 a_pol3 a_pol4 if Dist3cat==1 
    
lincom  polact1 + a_pol1*25     
lincom  polact1 + a_pol1*30     
lincom  polact1 + a_pol1*35     
lincom  polact1 + a_pol1*40     
lincom  polact1 + a_pol1*45     
lincom  polact1 + a_pol1*50     
lincom  polact1 + a_pol1*55     
lincom  polact1 + a_pol1*60     
lincom  polact1 + a_pol1*65     
lincom  polact1 + a_pol1*70    /* none sig */

/* Dist3cat==1 */
/*     polact2 */
lincom  polact2 + a_pol2*25     
lincom  polact2 + a_pol2*30     
lincom  polact2 + a_pol2*35     
lincom  polact2 + a_pol2*40     
lincom  polact2 + a_pol2*45     
lincom  polact2 + a_pol2*50     
lincom  polact2 + a_pol2*55     
lincom  polact2 + a_pol2*60     
lincom  polact2 + a_pol2*65     
lincom  polact2 + a_pol2*70    /* none sig */
   
/* Dist3cat==1 */
/*     polact3 */
lincom  polact3 + a_pol3*25     
lincom  polact3 + a_pol3*30     
lincom  polact3 + a_pol3*35     
lincom  polact3 + a_pol3*40     
lincom  polact3 + a_pol3*45     
lincom  polact3 + a_pol3*50     
lincom  polact3 + a_pol3*55     
lincom  polact3 + a_pol3*60     
lincom  polact3 + a_pol3*65     
lincom  polact3 + a_pol3*70    /* none sig */     

/* Dist3cat==1 */
/*     polact4 */
lincom  polact4 + a_pol4*25     
lincom  polact4 + a_pol4*30     
lincom  polact4 + a_pol4*35     
lincom  polact4 + a_pol4*40     
lincom  polact4 + a_pol4*45     
lincom  polact4 + a_pol4*50     
lincom  polact4 + a_pol4*55     
lincom  polact4 + a_pol4*60     
lincom  polact4 + a_pol4*65     
lincom  polact4 + a_pol4*70    /* none sig */     

/* Dist3cat==2 */
/*     polact1 */
regress DVshare age Mterms Mcands  ///
    dpj ldp cgp sdp jcp prim dpj_prim ldp_prim ///
    polact1 polact2 polact3 polact4 ///
    a_pol1 a_pol2 a_pol3 a_pol4 if Dist3cat==2 
    
lincom  polact1 + a_pol1*25     
lincom  polact1 + a_pol1*30     
lincom  polact1 + a_pol1*35     
lincom  polact1 + a_pol1*40     
lincom  polact1 + a_pol1*45     
lincom  polact1 + a_pol1*50     
lincom  polact1 + a_pol1*55     
lincom  polact1 + a_pol1*60     
lincom  polact1 + a_pol1*65     
lincom  polact1 + a_pol1*70  

lincom  polact1 + a_pol1*36     
lincom  polact1 + a_pol1*37     
lincom  polact1 + a_pol1*38     
lincom  polact1 + a_pol1*39  
/*
 ( 1)  polact1 + 39*a_pol1 = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   3.918471   2.000202     1.96   0.051    -.0188099    7.855753
------------------------------------------------------------------------------

 ( 1)  polact1 + 40*a_pol1 = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   3.805976   1.914996     1.99   0.048     .0364174    7.575535
------------------------------------------------------------------------------
*/

lincom  polact1 + a_pol1*51     
lincom  polact1 + a_pol1*52     
lincom  polact1 + a_pol1*53     
lincom  polact1 + a_pol1*54  

/*
 ( 1)  polact1 + 53*a_pol1 = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   2.343535   1.148833     2.04   0.042     .0821243    4.604945
------------------------------------------------------------------------------

 ( 1)  polact1 + 54*a_pol1 = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   2.231039   1.136783     1.96   0.051    -.0066531    4.468731
------------------------------------------------------------------------------
             <<<<< only 40-53 some effects */
   

/* Dist3cat==2 */
/*     polact2 */
lincom  polact2 + a_pol2*25     
lincom  polact2 + a_pol2*30     
lincom  polact2 + a_pol2*35     
lincom  polact2 + a_pol2*40     
lincom  polact2 + a_pol2*45     
lincom  polact2 + a_pol2*50     
lincom  polact2 + a_pol2*55     
lincom  polact2 + a_pol2*60     
lincom  polact2 + a_pol2*65     
lincom  polact2 + a_pol2*70     

lincom  polact2 + a_pol2*41     
lincom  polact2 + a_pol2*42     
lincom  polact2 + a_pol2*43     
lincom  polact2 + a_pol2*44 

/*
 ( 1)  polact2 + 35*a_pol2 = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   4.850818   2.322894     2.09   0.038     .2783356    9.423301
------------------------------------------------------------------------------

 ( 1)  polact2 + 40*a_pol2 = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   3.781878   1.875154     2.02   0.045      .090747     7.47301
------------------------------------------------------------------------------

 ( 1)  polact2 + 41*a_pol2 = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |    3.56809   1.791693     1.99   0.047     .0412465    7.094934
------------------------------------------------------------------------------

 ( 1)  polact2 + 42*a_pol2 = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   3.354302   1.710971     1.96   0.051    -.0136456     6.72225
------------------------------------------------------------------------------
             <<<<<  up to 41 effective */

/* Dist3cat==2 */
/*     polact3 */
lincom  polact3 + a_pol3*25     
lincom  polact3 + a_pol3*30     
lincom  polact3 + a_pol3*35     
lincom  polact3 + a_pol3*40     
lincom  polact3 + a_pol3*45     
lincom  polact3 + a_pol3*50     
lincom  polact3 + a_pol3*55     
lincom  polact3 + a_pol3*60     
lincom  polact3 + a_pol3*65     
lincom  polact3 + a_pol3*70    /* none sig */     

/* Dist3cat==2 */
/*     polact4 */
lincom  polact4 + a_pol4*25     
lincom  polact4 + a_pol4*30     
lincom  polact4 + a_pol4*35     
lincom  polact4 + a_pol4*40     
lincom  polact4 + a_pol4*45     
lincom  polact4 + a_pol4*50     
lincom  polact4 + a_pol4*55     
lincom  polact4 + a_pol4*60     
lincom  polact4 + a_pol4*65     
lincom  polact4 + a_pol4*70    /* none sig */     

/* Dist3cat==4 */
/*     polact1 */
regress DVshare age Mterms Mcands  ///
    dpj ldp cgp sdp jcp prim dpj_prim ldp_prim ///
    polact1 polact2 polact3 polact4 ///
    a_pol1 a_pol2 a_pol3 a_pol4 if Dist3cat==4 
    
lincom  polact1 + a_pol1*25     
lincom  polact1 + a_pol1*30     
lincom  polact1 + a_pol1*35     
lincom  polact1 + a_pol1*40     
lincom  polact1 + a_pol1*45     
lincom  polact1 + a_pol1*50     
lincom  polact1 + a_pol1*55     
lincom  polact1 + a_pol1*60     
lincom  polact1 + a_pol1*65     
lincom  polact1 + a_pol1*70

lincom  polact1 + a_pol1*51     
lincom  polact1 + a_pol1*52     
lincom  polact1 + a_pol1*53     
lincom  polact1 + a_pol1*54
/*
 ( 1)  polact1 + 51*a_pol1 = 0

------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   2.609225   1.231264     2.12   0.035     .1879857    5.030465
------------------------------------------------------------------------------

. lincom  polact1 + a_pol1*52     

 ( 1)  polact1 + 52*a_pol1 = 0

------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   2.342087   1.217128     1.92   0.055    -.0513551    4.735529
------------------------------------------------------------------------------*/
/*             <<<<<  up to 51 effective */




/* Dist3cat==4 */
/*     polact2 */
lincom  polact2 + a_pol2*25     
lincom  polact2 + a_pol2*30     
lincom  polact2 + a_pol2*35     
lincom  polact2 + a_pol2*40     
lincom  polact2 + a_pol2*45     
lincom  polact2 + a_pol2*50     
lincom  polact2 + a_pol2*55     
lincom  polact2 + a_pol2*60     
lincom  polact2 + a_pol2*65     
lincom  polact2 + a_pol2*70    /* none sig */     

/* Dist3cat==4 */
/*     polact3 */
lincom  polact3 + a_pol3*25     
lincom  polact3 + a_pol3*30     
lincom  polact3 + a_pol3*35     
lincom  polact3 + a_pol3*40     
lincom  polact3 + a_pol3*45     
lincom  polact3 + a_pol3*50     
lincom  polact3 + a_pol3*55     
lincom  polact3 + a_pol3*60     
lincom  polact3 + a_pol3*65     
lincom  polact3 + a_pol3*70    /* none sig */     

/* Dist3cat==4 */
/*     polact4 */
lincom  polact4 + a_pol4*25     
lincom  polact4 + a_pol4*30     
lincom  polact4 + a_pol4*35     
lincom  polact4 + a_pol4*40     
lincom  polact4 + a_pol4*45     
lincom  polact4 + a_pol4*50     
lincom  polact4 + a_pol4*55     
lincom  polact4 + a_pol4*60     
lincom  polact4 + a_pol4*65     
lincom  polact4 + a_pol4*70    /* none sig */     






/*:::::::::::::::: Table 10 :::::::::::::::::::*/
/* Dist3cat==1 */
/*     camact1 */
regress DVshare age Mterms Mcands  ///
    dpj ldp cgp sdp jcp prim dpj_prim ldp_prim ///
    camact1 camact2 camact3  ///
    a_cam1 a_cam2 a_cam3 if Dist3cat==1 
    
lincom  camact1 + a_cam1*25     
lincom  camact1 + a_cam1*30     
lincom  camact1 + a_cam1*35     
lincom  camact1 + a_cam1*40     
lincom  camact1 + a_cam1*45     
lincom  camact1 + a_cam1*50     
lincom  camact1 + a_cam1*55     
lincom  camact1 + a_cam1*60     
lincom  camact1 + a_cam1*65     
lincom  camact1 + a_cam1*70    /* none sig */  

/* Dist3cat==1 */
/*     camact2 */
lincom  camact2 + a_cam2*25     
lincom  camact2 + a_cam2*30     
lincom  camact2 + a_cam2*35     
lincom  camact2 + a_cam2*40     
lincom  camact2 + a_cam2*45     
lincom  camact2 + a_cam2*50     
lincom  camact2 + a_cam2*55     
lincom  camact2 + a_cam2*60     
lincom  camact2 + a_cam2*65     
lincom  camact2 + a_cam2*70 

lincom  camact2 + a_cam2*56     
lincom  camact2 + a_cam2*57     
lincom  camact2 + a_cam2*58     
lincom  camact2 + a_cam2*59 

lincom  camact2 + a_cam2*66     
lincom  camact2 + a_cam2*67     
lincom  camact2 + a_cam2*68     
lincom  camact2 + a_cam2*69 
/*
 ( 1)  camact2 + 56*a_cam2 = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |  -3.526051    1.81444    -1.94   0.055      -7.1349     .082798
------------------------------------------------------------------------------

 ( 1)  camact2 + 57*a_cam2 = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |  -3.651691    1.80526    -2.02   0.046     -7.24228   -.0611017
------------------------------------------------------------------------------

 ( 1)  camact2 + 68*a_cam2 = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |  -5.033733   2.502441    -2.01   0.048    -10.01099   -.0564786
------------------------------------------------------------------------------

 ( 1)  camact2 + 69*a_cam2 = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |  -5.159373   2.615624    -1.97   0.052    -10.36174    .0429967
------------------------------------------------------------------------------
            <<<<<  57-68 some negative effects  */

/* Dist3cat==1 */
/*     camact3 */
lincom  camact3 + a_cam3*25     
lincom  camact3 + a_cam3*30     
lincom  camact3 + a_cam3*35     
lincom  camact3 + a_cam3*40     
lincom  camact3 + a_cam3*45     
lincom  camact3 + a_cam3*50     
lincom  camact3 + a_cam3*55     
lincom  camact3 + a_cam3*60     
lincom  camact3 + a_cam3*65     
lincom  camact3 + a_cam3*70 

lincom  camact3 + a_cam3*46     
lincom  camact3 + a_cam3*47     
lincom  camact3 + a_cam3*48     
lincom  camact3 + a_cam3*49 

lincom  camact3 + a_cam3*61     
lincom  camact3 + a_cam3*62     
lincom  camact3 + a_cam3*63     
lincom  camact3 + a_cam3*64 
/*
 ( 1)  camact3 + 46*a_cam3 = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   5.099067   2.578237     1.98   0.051    -.0289412    10.22708
------------------------------------------------------------------------------

 ( 1)  camact3 + 47*a_cam3 = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   5.089526   2.420926     2.10   0.039     .2744007    9.904651
------------------------------------------------------------------------------

 ( 1)  camact3 + 64*a_cam3 = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   4.927314   2.418053     2.04   0.045     .1179045    9.736724
------------------------------------------------------------------------------

 ( 1)  camact3 + 65*a_cam3 = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   4.917772   2.575221     1.91   0.060    -.2042385    10.03978
------------------------------------------------------------------------------
             <<<<<  47-64 some effects */



/* Dist3cat==2 */
/*     camact1 */
regress DVshare age Mterms Mcands  ///
    dpj ldp cgp sdp jcp prim dpj_prim ldp_prim ///
    camact1 camact2 camact3  ///
    a_cam1 a_cam2 a_cam3 if Dist3cat==2 

lincom  camact1 + a_cam1*25     
lincom  camact1 + a_cam1*30     
lincom  camact1 + a_cam1*35     
lincom  camact1 + a_cam1*40     
lincom  camact1 + a_cam1*45     
lincom  camact1 + a_cam1*50     
lincom  camact1 + a_cam1*55     
lincom  camact1 + a_cam1*60     
lincom  camact1 + a_cam1*65     
lincom  camact1 + a_cam1*70     /* none sig */

/* Dist3cat==2 */
/*     camact2 */
lincom  camact2 + a_cam2*25     
lincom  camact2 + a_cam2*30     
lincom  camact2 + a_cam2*35     
lincom  camact2 + a_cam2*40     
lincom  camact2 + a_cam2*45     
lincom  camact2 + a_cam2*50     
lincom  camact2 + a_cam2*55     
lincom  camact2 + a_cam2*60     
lincom  camact2 + a_cam2*65     
lincom  camact2 + a_cam2*70    /* none sig */ 

/* Dist3cat==2 */
/*     camact3 */
lincom  camact3 + a_cam3*25     
lincom  camact3 + a_cam3*30     
lincom  camact3 + a_cam3*35     
lincom  camact3 + a_cam3*40     
lincom  camact3 + a_cam3*45     
lincom  camact3 + a_cam3*50     
lincom  camact3 + a_cam3*55     
lincom  camact3 + a_cam3*60     
lincom  camact3 + a_cam3*65     
lincom  camact3 + a_cam3*70    /* none sig */ 


/* Dist3cat==4 */
/*     camact1 */
regress DVshare age Mterms Mcands  ///
    dpj ldp cgp sdp jcp prim dpj_prim ldp_prim ///
    camact1 camact2 camact3  ///
    a_cam1 a_cam2 a_cam3 if Dist3cat==4 
    
lincom  camact1 + a_cam1*25     
lincom  camact1 + a_cam1*30     
lincom  camact1 + a_cam1*35     
lincom  camact1 + a_cam1*40     
lincom  camact1 + a_cam1*45     
lincom  camact1 + a_cam1*50     
lincom  camact1 + a_cam1*55     
lincom  camact1 + a_cam1*60     
lincom  camact1 + a_cam1*65     
lincom  camact1 + a_cam1*70    /* none sig */ 

/* Dist3cat==4 */
/*     camact2 */
lincom  camact2 + a_cam2*25     
lincom  camact2 + a_cam2*30     
lincom  camact2 + a_cam2*35     
lincom  camact2 + a_cam2*40     
lincom  camact2 + a_cam2*45     
lincom  camact2 + a_cam2*50     
lincom  camact2 + a_cam2*55     
lincom  camact2 + a_cam2*60     
lincom  camact2 + a_cam2*65     
lincom  camact2 + a_cam2*70    /* none sig */ 

/* Dist3cat==4 */
/*     camact3 */
lincom  camact3 + a_cam3*25     
lincom  camact3 + a_cam3*30     
lincom  camact3 + a_cam3*35     
lincom  camact3 + a_cam3*40     
lincom  camact3 + a_cam3*45     
lincom  camact3 + a_cam3*50     
lincom  camact3 + a_cam3*55     
lincom  camact3 + a_cam3*60     
lincom  camact3 + a_cam3*65     
lincom  camact3 + a_cam3*70    /* none sig */ 





/*:::::::::::::::: Table 11 :::::::::::::::::::*/
/* Dist3cat==1 */
/*     sup_shug */
regress DVshare age Mterms Mcands  ///
    dpj ldp cgp sdp jcp prim dpj_prim ldp_prim ///
    sup_shug sup_sang sup_govn sup_mayo sup_city  ///
    a_s_shug a_s_sang a_s_govn a_s_mayo a_s_city if Dist3cat==1 
    
lincom  sup_shug + a_s_shug*25     
lincom  sup_shug + a_s_shug*30     
lincom  sup_shug + a_s_shug*35     
lincom  sup_shug + a_s_shug*40     
lincom  sup_shug + a_s_shug*45     
lincom  sup_shug + a_s_shug*50     
lincom  sup_shug + a_s_shug*55     
lincom  sup_shug + a_s_shug*60     
lincom  sup_shug + a_s_shug*65     
lincom  sup_shug + a_s_shug*70    /* none sig */

/* Dist3cat==1 */
/*     sup_sang */
lincom  sup_sang + a_s_sang*25     
lincom  sup_sang + a_s_sang*30     
lincom  sup_sang + a_s_sang*35     
lincom  sup_sang + a_s_sang*40     
lincom  sup_sang + a_s_sang*45     
lincom  sup_sang + a_s_sang*50     
lincom  sup_sang + a_s_sang*55     
lincom  sup_sang + a_s_sang*60     
lincom  sup_sang + a_s_sang*65     
lincom  sup_sang + a_s_sang*70    /* none sig */ 

/* Dist3cat==1 */
/*     sup_govn */
lincom  sup_govn + a_s_govn*25     
lincom  sup_govn + a_s_govn*30     
lincom  sup_govn + a_s_govn*35     
lincom  sup_govn + a_s_govn*40     
lincom  sup_govn + a_s_govn*45     
lincom  sup_govn + a_s_govn*50     
lincom  sup_govn + a_s_govn*55     
lincom  sup_govn + a_s_govn*60     
lincom  sup_govn + a_s_govn*65     
lincom  sup_govn + a_s_govn*70    /* none sig */ 

/* Dist3cat==1 */
/*     sup_mayo */
lincom  sup_mayo + a_s_mayo*25     
lincom  sup_mayo + a_s_mayo*30     
lincom  sup_mayo + a_s_mayo*35     
lincom  sup_mayo + a_s_mayo*40     
lincom  sup_mayo + a_s_mayo*45     
lincom  sup_mayo + a_s_mayo*50     
lincom  sup_mayo + a_s_mayo*55     
lincom  sup_mayo + a_s_mayo*60     
lincom  sup_mayo + a_s_mayo*65     
lincom  sup_mayo + a_s_mayo*70    /* none sig */ 

/* Dist3cat==1 */
/*     sup_city */
lincom  sup_city + a_s_city*25     
lincom  sup_city + a_s_city*30     
lincom  sup_city + a_s_city*35     
lincom  sup_city + a_s_city*40     
lincom  sup_city + a_s_city*45     
lincom  sup_city + a_s_city*50     
lincom  sup_city + a_s_city*55     
lincom  sup_city + a_s_city*60     
lincom  sup_city + a_s_city*65     
lincom  sup_city + a_s_city*70    /* none sig */ 


/* Dist3cat==2 */
/*     sup_shug */
regress DVshare age Mterms Mcands  ///
    dpj ldp cgp sdp jcp prim dpj_prim ldp_prim ///
    sup_shug sup_sang sup_govn sup_mayo sup_city  ///
    a_s_shug a_s_sang a_s_govn a_s_mayo a_s_city if Dist3cat==2 

lincom prim + dpj_prim
lincom prim + ldp_prim       /* none sig */ 
    
lincom  sup_shug + a_s_shug*25     
lincom  sup_shug + a_s_shug*30     
lincom  sup_shug + a_s_shug*35     
lincom  sup_shug + a_s_shug*40     
lincom  sup_shug + a_s_shug*45     
lincom  sup_shug + a_s_shug*50     
lincom  sup_shug + a_s_shug*55     
lincom  sup_shug + a_s_shug*60     
lincom  sup_shug + a_s_shug*65     
lincom  sup_shug + a_s_shug*70    /* none sig */ 

/* Dist3cat==2 */
/*     sup_sang */
lincom  sup_sang + a_s_sang*25     
lincom  sup_sang + a_s_sang*30     
lincom  sup_sang + a_s_sang*35     
lincom  sup_sang + a_s_sang*40     
lincom  sup_sang + a_s_sang*45     
lincom  sup_sang + a_s_sang*50     
lincom  sup_sang + a_s_sang*55     
lincom  sup_sang + a_s_sang*60     
lincom  sup_sang + a_s_sang*65     
lincom  sup_sang + a_s_sang*70    /* none sig */ 

/* Dist3cat==2 */
/*     sup_govn */
lincom  sup_govn + a_s_govn*25     
lincom  sup_govn + a_s_govn*30     
lincom  sup_govn + a_s_govn*35     
lincom  sup_govn + a_s_govn*40     
lincom  sup_govn + a_s_govn*45     
lincom  sup_govn + a_s_govn*50     
lincom  sup_govn + a_s_govn*55     
lincom  sup_govn + a_s_govn*60     
lincom  sup_govn + a_s_govn*65     
lincom  sup_govn + a_s_govn*70    /* none sig */ 

/* Dist3cat==2 */
/*     sup_mayo */
lincom  sup_mayo + a_s_mayo*25     
lincom  sup_mayo + a_s_mayo*30     
lincom  sup_mayo + a_s_mayo*35     
lincom  sup_mayo + a_s_mayo*40     
lincom  sup_mayo + a_s_mayo*45     
lincom  sup_mayo + a_s_mayo*50     
lincom  sup_mayo + a_s_mayo*55     
lincom  sup_mayo + a_s_mayo*60     
lincom  sup_mayo + a_s_mayo*65     
lincom  sup_mayo + a_s_mayo*70    /* none sig */ 

/* Dist3cat==2 */
/*     sup_city */
lincom  sup_city + a_s_city*25     
lincom  sup_city + a_s_city*30     
lincom  sup_city + a_s_city*35     
lincom  sup_city + a_s_city*40     
lincom  sup_city + a_s_city*45     
lincom  sup_city + a_s_city*50     
lincom  sup_city + a_s_city*55     
lincom  sup_city + a_s_city*60     
lincom  sup_city + a_s_city*65     
lincom  sup_city + a_s_city*70    /* none sig */ 

/* Dist3cat==4 */
/*     sup_shug */
regress DVshare age Mterms Mcands  ///
    dpj ldp cgp sdp jcp prim dpj_prim ldp_prim ///
    sup_shug sup_sang sup_govn sup_mayo sup_city  ///
    a_s_shug a_s_sang a_s_govn a_s_mayo a_s_city if Dist3cat==4 
    
lincom  sup_shug + a_s_shug*25     
lincom  sup_shug + a_s_shug*30     
lincom  sup_shug + a_s_shug*35     
lincom  sup_shug + a_s_shug*40     
lincom  sup_shug + a_s_shug*45     
lincom  sup_shug + a_s_shug*50     
lincom  sup_shug + a_s_shug*55     
lincom  sup_shug + a_s_shug*60     
lincom  sup_shug + a_s_shug*65     
lincom  sup_shug + a_s_shug*70 

lincom  sup_shug + a_s_shug*46     
lincom  sup_shug + a_s_shug*47     
lincom  sup_shug + a_s_shug*48     
lincom  sup_shug + a_s_shug*49 
/*
 ( 1)  sup_shug + 48*a_s_shug = 0

------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   -2.28578   1.151204    -1.99   0.048    -4.551755   -.0198049
------------------------------------------------------------------------------

. lincom  sup_shug + a_s_shug*49 

 ( 1)  sup_shug + 49*a_s_shug = 0

------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |  -2.103552   1.132762    -1.86   0.064    -4.333226    .1261215
------------------------------------------------------------------------------
            <<<<<  up to 48 negative effects  */


/* Dist3cat==4 */
/*     sup_sang */
lincom  sup_sang + a_s_sang*25     
lincom  sup_sang + a_s_sang*30     
lincom  sup_sang + a_s_sang*35     
lincom  sup_sang + a_s_sang*40     
lincom  sup_sang + a_s_sang*45     
lincom  sup_sang + a_s_sang*50     
lincom  sup_sang + a_s_sang*55     
lincom  sup_sang + a_s_sang*60     
lincom  sup_sang + a_s_sang*65     
lincom  sup_sang + a_s_sang*70    /* none sig */ 

/* Dist3cat==4 */
/*     sup_govn */
lincom  sup_govn + a_s_govn*25     
lincom  sup_govn + a_s_govn*30     
lincom  sup_govn + a_s_govn*35     
lincom  sup_govn + a_s_govn*40     
lincom  sup_govn + a_s_govn*45     
lincom  sup_govn + a_s_govn*50     
lincom  sup_govn + a_s_govn*55     
lincom  sup_govn + a_s_govn*60     
lincom  sup_govn + a_s_govn*65     
lincom  sup_govn + a_s_govn*70    /* none sig */ 

/* Dist3cat==4 */
/*     sup_mayo */
lincom  sup_mayo + a_s_mayo*25     
lincom  sup_mayo + a_s_mayo*30     
lincom  sup_mayo + a_s_mayo*35     
lincom  sup_mayo + a_s_mayo*40     
lincom  sup_mayo + a_s_mayo*45     
lincom  sup_mayo + a_s_mayo*50     
lincom  sup_mayo + a_s_mayo*55     
lincom  sup_mayo + a_s_mayo*60     
lincom  sup_mayo + a_s_mayo*65     
lincom  sup_mayo + a_s_mayo*70    /* none sig */ 

/* Dist3cat==4 */
/*     sup_city */
lincom  sup_city + a_s_city*25     
lincom  sup_city + a_s_city*30     
lincom  sup_city + a_s_city*35     
lincom  sup_city + a_s_city*40     
lincom  sup_city + a_s_city*45     
lincom  sup_city + a_s_city*50     
lincom  sup_city + a_s_city*55     
lincom  sup_city + a_s_city*60     
lincom  sup_city + a_s_city*65     
lincom  sup_city + a_s_city*70    /* none sig */ 



/*:::::::::::::::: Table 12 :::::::::::::::::::*/
/* Dist3cat==1 */
/*     hel_shug */
regress DVshare age Mterms Mcands  ///
    dpj ldp cgp sdp jcp prim dpj_prim ldp_prim ///
    hel_shug hel_sang hel_govn hel_mayo hel_city  ///
    a_h_shug a_h_sang a_h_govn a_h_mayo a_h_city if Dist3cat==1 
        
lincom  hel_shug + a_h_shug*25     
lincom  hel_shug + a_h_shug*30     
lincom  hel_shug + a_h_shug*35     
lincom  hel_shug + a_h_shug*40     
lincom  hel_shug + a_h_shug*45     
lincom  hel_shug + a_h_shug*50     
lincom  hel_shug + a_h_shug*55     
lincom  hel_shug + a_h_shug*60     
lincom  hel_shug + a_h_shug*65     
lincom  hel_shug + a_h_shug*70     /* none sig */

/* Dist3cat==1 */
/*     hel_sang */
lincom  hel_sang + a_h_sang*25     
lincom  hel_sang + a_h_sang*30     
lincom  hel_sang + a_h_sang*35     
lincom  hel_sang + a_h_sang*40     
lincom  hel_sang + a_h_sang*45     
lincom  hel_sang + a_h_sang*50     
lincom  hel_sang + a_h_sang*55     
lincom  hel_sang + a_h_sang*60     
lincom  hel_sang + a_h_sang*65     
lincom  hel_sang + a_h_sang*70     /* none sig */

/* Dist3cat==1 */
/*     hel_govn */
lincom  hel_govn + a_h_govn*25     
lincom  hel_govn + a_h_govn*30     
lincom  hel_govn + a_h_govn*35     
lincom  hel_govn + a_h_govn*40     
lincom  hel_govn + a_h_govn*45     
lincom  hel_govn + a_h_govn*50     
lincom  hel_govn + a_h_govn*55     
lincom  hel_govn + a_h_govn*60     
lincom  hel_govn + a_h_govn*65     
lincom  hel_govn + a_h_govn*70     /* none sig */

/* Dist3cat==1 */
/*     hel_mayo */
lincom  hel_mayo + a_h_mayo*25     
lincom  hel_mayo + a_h_mayo*30     
lincom  hel_mayo + a_h_mayo*35     
lincom  hel_mayo + a_h_mayo*40     
lincom  hel_mayo + a_h_mayo*45     
lincom  hel_mayo + a_h_mayo*50     
lincom  hel_mayo + a_h_mayo*55     
lincom  hel_mayo + a_h_mayo*60     
lincom  hel_mayo + a_h_mayo*65     
lincom  hel_mayo + a_h_mayo*70    /* none sig */ 

/* Dist3cat==1 */
/*     hel_city */
lincom  hel_city + a_h_city*25     
lincom  hel_city + a_h_city*30     
lincom  hel_city + a_h_city*35     
lincom  hel_city + a_h_city*40     
lincom  hel_city + a_h_city*45     
lincom  hel_city + a_h_city*50     
lincom  hel_city + a_h_city*55     
lincom  hel_city + a_h_city*60     
lincom  hel_city + a_h_city*65     
lincom  hel_city + a_h_city*70    /* none sig */ 


/* Dist3cat==2 */
/*     hel_shug */
regress DVshare age Mterms Mcands  ///
    dpj ldp cgp sdp jcp prim dpj_prim ldp_prim ///
    hel_shug hel_sang hel_govn hel_mayo hel_city  ///
    a_h_shug a_h_sang a_h_govn a_h_mayo a_h_city if Dist3cat==2 

lincom  hel_shug + a_h_shug*25     
lincom  hel_shug + a_h_shug*30     
lincom  hel_shug + a_h_shug*35     
lincom  hel_shug + a_h_shug*40     
lincom  hel_shug + a_h_shug*45     
lincom  hel_shug + a_h_shug*50     
lincom  hel_shug + a_h_shug*55     
lincom  hel_shug + a_h_shug*60     
lincom  hel_shug + a_h_shug*65     
lincom  hel_shug + a_h_shug*70 

lincom  hel_shug + a_h_shug*51     
lincom  hel_shug + a_h_shug*52     
lincom  hel_shug + a_h_shug*53     
lincom  hel_shug + a_h_shug*54 

lincom  hel_shug + a_h_shug*61     
lincom  hel_shug + a_h_shug*62     
lincom  hel_shug + a_h_shug*63     
lincom  hel_shug + a_h_shug*64 

/*
 ( 1)  hel_shug + 50*a_h_shug = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   2.246022   1.146223     1.96   0.051    -.0131923    4.505235
------------------------------------------------------------------------------

 ( 1)  hel_shug + 51*a_h_shug = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   2.277941   1.124802     2.03   0.044     .0609471    4.494935
------------------------------------------------------------------------------

 ( 1)  hel_shug + 52*a_h_shug = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |    2.30986    1.11147     2.08   0.039     .1191442    4.500577
------------------------------------------------------------------------------

 ( 1)  hel_shug + 60*a_h_shug = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   2.565216   1.294146     1.98   0.049     .0144437    5.115988
------------------------------------------------------------------------------

 ( 1)  hel_shug + 61*a_h_shug = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   2.597136   1.347031     1.93   0.055    -.0578718    5.252143
------------------------------------------------------------------------------

 ( 1)  hel_shug + 62*a_h_shug = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |   2.629055   1.404635     1.87   0.063    -.1394915    5.397601
------------------------------------------------------------------------------
             <<<<<  only 51-60 effective   */


/* Dist3cat==2 */
/*     hel_sang */
lincom  hel_sang + a_h_sang*25     
lincom  hel_sang + a_h_sang*30     
lincom  hel_sang + a_h_sang*35     
lincom  hel_sang + a_h_sang*40     
lincom  hel_sang + a_h_sang*45     
lincom  hel_sang + a_h_sang*50     
lincom  hel_sang + a_h_sang*55     
lincom  hel_sang + a_h_sang*60     
lincom  hel_sang + a_h_sang*65     
lincom  hel_sang + a_h_sang*70    /* none sig */  

/* Dist3cat==2 */
/*     hel_govn */
lincom  hel_govn + a_h_govn*25     
lincom  hel_govn + a_h_govn*30     
lincom  hel_govn + a_h_govn*35     
lincom  hel_govn + a_h_govn*40     
lincom  hel_govn + a_h_govn*45     
lincom  hel_govn + a_h_govn*50     
lincom  hel_govn + a_h_govn*55     
lincom  hel_govn + a_h_govn*60     
lincom  hel_govn + a_h_govn*65     
lincom  hel_govn + a_h_govn*70 

lincom  hel_govn + a_h_govn*51     
lincom  hel_govn + a_h_govn*52     
lincom  hel_govn + a_h_govn*53     
lincom  hel_govn + a_h_govn*54 

/*
 ( 1)  hel_govn + 52*a_h_govn = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |  -1.590285   .8327918    -1.91   0.058    -3.231724    .0511538
------------------------------------------------------------------------------

 ( 1)  hel_govn + 53*a_h_govn = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |  -1.690797   .8256183    -2.05   0.042    -3.318097   -.0634971
------------------------------------------------------------------------------

 ( 1)  hel_govn + 54*a_h_govn = 0
------------------------------------------------------------------------------
     DVshare |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
         (1) |  -1.791309   .8254657    -2.17   0.031    -3.418308   -.1643096
------------------------------------------------------------------------------
             <<<<<  starting 53, some negative effects  */


/* Dist3cat==2 */
/*     hel_mayo */
lincom  hel_mayo + a_h_mayo*25     
lincom  hel_mayo + a_h_mayo*30     
lincom  hel_mayo + a_h_mayo*35     
lincom  hel_mayo + a_h_mayo*40     
lincom  hel_mayo + a_h_mayo*45     
lincom  hel_mayo + a_h_mayo*50     
lincom  hel_mayo + a_h_mayo*55     
lincom  hel_mayo + a_h_mayo*60     
lincom  hel_mayo + a_h_mayo*65     
lincom  hel_mayo + a_h_mayo*70    /* none sig */ 

/* Dist3cat==2 */
/*     hel_city */
lincom  hel_city + a_h_city*25     
lincom  hel_city + a_h_city*30     
lincom  hel_city + a_h_city*35     
lincom  hel_city + a_h_city*40     
lincom  hel_city + a_h_city*45     
lincom  hel_city + a_h_city*50     
lincom  hel_city + a_h_city*55     
lincom  hel_city + a_h_city*60     
lincom  hel_city + a_h_city*65     
lincom  hel_city + a_h_city*70    /* none sig */ 


/* Dist3cat==4 */
/*     hel_shug */
regress DVshare age Mterms Mcands  ///
    dpj ldp cgp sdp jcp prim dpj_prim ldp_prim ///
    hel_shug hel_sang hel_govn hel_mayo hel_city  ///
    a_h_shug a_h_sang a_h_govn a_h_mayo a_h_city if Dist3cat==4 

lincom  hel_shug + a_h_shug*25     
lincom  hel_shug + a_h_shug*30     
lincom  hel_shug + a_h_shug*35     
lincom  hel_shug + a_h_shug*40     
lincom  hel_shug + a_h_shug*45     
lincom  hel_shug + a_h_shug*50     
lincom  hel_shug + a_h_shug*55     
lincom  hel_shug + a_h_shug*60     
lincom  hel_shug + a_h_shug*65     
lincom  hel_shug + a_h_shug*70    /* none sig */ 

/* Dist3cat==4 */
/*     hel_sang */
lincom  hel_sang + a_h_sang*25     
lincom  hel_sang + a_h_sang*30     
lincom  hel_sang + a_h_sang*35     
lincom  hel_sang + a_h_sang*40     
lincom  hel_sang + a_h_sang*45     
lincom  hel_sang + a_h_sang*50     
lincom  hel_sang + a_h_sang*55     
lincom  hel_sang + a_h_sang*60     
lincom  hel_sang + a_h_sang*65     
lincom  hel_sang + a_h_sang*70    /* none sig */ 

/* Dist3cat==4 */
/*     hel_govn */
lincom  hel_govn + a_h_govn*25     
lincom  hel_govn + a_h_govn*30     
lincom  hel_govn + a_h_govn*35     
lincom  hel_govn + a_h_govn*40     
lincom  hel_govn + a_h_govn*45     
lincom  hel_govn + a_h_govn*50     
lincom  hel_govn + a_h_govn*55     
lincom  hel_govn + a_h_govn*60     
lincom  hel_govn + a_h_govn*65     
lincom  hel_govn + a_h_govn*70    /* none sig */ 

/* Dist3cat==4 */
/*     hel_mayo */
lincom  hel_mayo + a_h_mayo*25     
lincom  hel_mayo + a_h_mayo*30     
lincom  hel_mayo + a_h_mayo*35     
lincom  hel_mayo + a_h_mayo*40     
lincom  hel_mayo + a_h_mayo*45     
lincom  hel_mayo + a_h_mayo*50     
lincom  hel_mayo + a_h_mayo*55     
lincom  hel_mayo + a_h_mayo*60     
lincom  hel_mayo + a_h_mayo*65     
lincom  hel_mayo + a_h_mayo*70    /* none sig */ 

/* Dist3cat==4 */
/*     hel_city */
lincom  hel_city + a_h_city*25     
lincom  hel_city + a_h_city*30     
lincom  hel_city + a_h_city*35     
lincom  hel_city + a_h_city*40     
lincom  hel_city + a_h_city*45     
lincom  hel_city + a_h_city*50     
lincom  hel_city + a_h_city*55     
lincom  hel_city + a_h_city*60     
lincom  hel_city + a_h_city*65     
lincom  hel_city + a_h_city*70 



/*:::::::::::::::: Table 11*   with LDP sample only :::::::::::::::::::*/
/* ldp==1 */
/*     sup_shug */
regress DVshare age Mterms Mcands  ///
                  prim         ///
    sup_shug sup_sang sup_govn sup_mayo sup_city  ///
    a_s_shug a_s_sang a_s_govn a_s_mayo a_s_city if ldp==1     /* none sig */
        
lincom  sup_shug + a_s_shug*25     
lincom  sup_shug + a_s_shug*30     
lincom  sup_shug + a_s_shug*35     
lincom  sup_shug + a_s_shug*40     
lincom  sup_shug + a_s_shug*45     
lincom  sup_shug + a_s_shug*50     
lincom  sup_shug + a_s_shug*55     
lincom  sup_shug + a_s_shug*60     
lincom  sup_shug + a_s_shug*65     
lincom  sup_shug + a_s_shug*70    /* none sig */

/*     sup_sang */
lincom  sup_sang + a_s_sang*25     
lincom  sup_sang + a_s_sang*30     
lincom  sup_sang + a_s_sang*35     
lincom  sup_sang + a_s_sang*40     
lincom  sup_sang + a_s_sang*45     
lincom  sup_sang + a_s_sang*50     
lincom  sup_sang + a_s_sang*55     
lincom  sup_sang + a_s_sang*60     
lincom  sup_sang + a_s_sang*65     
lincom  sup_sang + a_s_sang*70    /* none sig */ 

/*     sup_govn */
lincom  sup_govn + a_s_govn*25     
lincom  sup_govn + a_s_govn*30     
lincom  sup_govn + a_s_govn*35     
lincom  sup_govn + a_s_govn*40     
lincom  sup_govn + a_s_govn*45     
lincom  sup_govn + a_s_govn*50     
lincom  sup_govn + a_s_govn*55     
lincom  sup_govn + a_s_govn*60     
lincom  sup_govn + a_s_govn*65     
lincom  sup_govn + a_s_govn*70    /* none sig */ 

/*     sup_mayo */
lincom  sup_mayo + a_s_mayo*25     
lincom  sup_mayo + a_s_mayo*30     
lincom  sup_mayo + a_s_mayo*35     
lincom  sup_mayo + a_s_mayo*40     
lincom  sup_mayo + a_s_mayo*45     
lincom  sup_mayo + a_s_mayo*50     
lincom  sup_mayo + a_s_mayo*55     
lincom  sup_mayo + a_s_mayo*60     
lincom  sup_mayo + a_s_mayo*65     
lincom  sup_mayo + a_s_mayo*70    /* 50-60 sig */ 

/*     sup_city */
lincom  sup_city + a_s_city*25     
lincom  sup_city + a_s_city*30     
lincom  sup_city + a_s_city*35     
lincom  sup_city + a_s_city*40     
lincom  sup_city + a_s_city*45     
lincom  sup_city + a_s_city*50     
lincom  sup_city + a_s_city*55     
lincom  sup_city + a_s_city*60     
lincom  sup_city + a_s_city*65     
lincom  sup_city + a_s_city*70    /* none sig */ 



/*:::::::::::::::: Table 12*   with LDP sample only :::::::::::::::::::*/
/* ldp==1 */
/*     hel_shug */
regress DVshare age Mterms Mcands  ///
           prim     ///
    hel_shug hel_sang hel_govn hel_mayo hel_city  ///
    a_h_shug a_h_sang a_h_govn a_h_mayo a_h_city if ldp==1 
        
lincom  hel_shug + a_h_shug*25     
lincom  hel_shug + a_h_shug*30     
lincom  hel_shug + a_h_shug*35     
lincom  hel_shug + a_h_shug*40     
lincom  hel_shug + a_h_shug*45     
lincom  hel_shug + a_h_shug*50     
lincom  hel_shug + a_h_shug*55     
lincom  hel_shug + a_h_shug*60     
lincom  hel_shug + a_h_shug*65     
lincom  hel_shug + a_h_shug*70     /* none sig */

/*     hel_sang */
lincom  hel_sang + a_h_sang*25     
lincom  hel_sang + a_h_sang*30     
lincom  hel_sang + a_h_sang*35     
lincom  hel_sang + a_h_sang*40     
lincom  hel_sang + a_h_sang*45     
lincom  hel_sang + a_h_sang*50     
lincom  hel_sang + a_h_sang*55     
lincom  hel_sang + a_h_sang*60     
lincom  hel_sang + a_h_sang*65     
lincom  hel_sang + a_h_sang*70     /* none sig */

/*     hel_govn */
lincom  hel_govn + a_h_govn*25     
lincom  hel_govn + a_h_govn*30     
lincom  hel_govn + a_h_govn*35     
lincom  hel_govn + a_h_govn*40     
lincom  hel_govn + a_h_govn*45     
lincom  hel_govn + a_h_govn*50     
lincom  hel_govn + a_h_govn*55     
lincom  hel_govn + a_h_govn*60     
lincom  hel_govn + a_h_govn*65     
lincom  hel_govn + a_h_govn*70     /* 40-45 sig */

/*     hel_mayo */
lincom  hel_mayo + a_h_mayo*25     
lincom  hel_mayo + a_h_mayo*30     
lincom  hel_mayo + a_h_mayo*35     
lincom  hel_mayo + a_h_mayo*40     
lincom  hel_mayo + a_h_mayo*45     
lincom  hel_mayo + a_h_mayo*50     
lincom  hel_mayo + a_h_mayo*55     
lincom  hel_mayo + a_h_mayo*60     
lincom  hel_mayo + a_h_mayo*65     
lincom  hel_mayo + a_h_mayo*70    /* none sig */ 

/*     hel_city */
lincom  hel_city + a_h_city*25     
lincom  hel_city + a_h_city*30     
lincom  hel_city + a_h_city*35     
lincom  hel_city + a_h_city*40     
lincom  hel_city + a_h_city*45     
lincom  hel_city + a_h_city*50     
lincom  hel_city + a_h_city*55     
lincom  hel_city + a_h_city*60     
lincom  hel_city + a_h_city*65     
lincom  hel_city + a_h_city*70    /* none sig */ 


/* end of file */
